@@ -23,4 +23,4 @@
  *
  */
 
-let LOCALE_DIR = '/usr/local/share/locale';
+var LOCALE_DIR = '/usr/local/share/locale';
